"use client";

import * as React from "react";

import { cn } from "@/lib/utils";

interface FAQItemProps {
  question: string;
  answer: string;
  isRTL?: boolean;
}

export function FAQItem({ question, answer, isRTL = false }: FAQItemProps) {
  const [isOpen, setIsOpen] = React.useState(false);

  return (
    <div
      className={cn(
        "transition-all duration-200",
        isOpen && "shadow-[0_20px_16px_-8px_rgba(0,0,0,0.1)]"
      )}
    >
      <button
        onClick={() => setIsOpen(!isOpen)}
        className={cn(
          "flex w-full items-center justify-between border-b py-4 text-left text-xl font-medium text-[#10131C] transition-all hover:text-blue-500",
          isRTL && "text-right"
        )}
      >
        <span>{question}</span>
        <div
          className={cn(
            "flex h-8 w-8 items-center justify-center rounded-full border border-gray-300",
            isRTL && "-scale-x-100"
          )}
        >
          <svg
            width="14"
            height="14"
            viewBox="0 0 14 14"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
            className={cn(
              "transition-transform duration-200",
              isOpen && "rotate-180"
            )}
          >
            <path
              d="M3.5 3.5L10.5 10.5"
              stroke="currentColor"
              strokeWidth="1.5"
              strokeLinecap="round"
              strokeLinejoin="round"
            />
            <path
              d="M10.5 3.5V10.5H3.5"
              stroke="currentColor"
              strokeWidth="1.5"
              strokeLinecap="round"
              strokeLinejoin="round"
            />
          </svg>
        </div>
      </button>
      {isOpen && (
        <div className="py-4">
          <p
            className={cn(
              "text-justify text-base text-[#646464]",
              isRTL && "text-right"
            )}
          >
            {answer}
          </p>
        </div>
      )}
    </div>
  );
}
